pub enum ExpressionError {
InvalidMleIndex,
EvaluationError(&'static str),
MleError(MleError),
SelectorBitNotBoundError,
EvaluateNotFullyBoundError,
EvaluateNotFullyIndexedError,
EvaluateBoundIndicesDontMatch,
TranscriptError(TranscriptReaderError),
}Expand description
Error for handling the parsing and evaluation of expressions.
Variants
InvalidMleIndex
Error for when an InvalidMleIndex is found while evaluating an expression TODO!(add some diagnoistics here)
EvaluationError(&'static str)
Error for when something unlikely goes wrong while evaluating an expression TODO!(split this up into many error variants)
MleError(MleError)
Error that wraps an MleError.
SelectorBitNotBoundError
Selector bit not bound before final evaluation gather.
EvaluateNotFullyBoundError
MLE ref with more than one element in its bookkeeping table.
EvaluateNotFullyIndexedError
During evaluation, an MLE should not contain crate::mle::MleIndex::Free variables.
EvaluateBoundIndicesDontMatch
The bound indices of this expression don’t match the indices passed in.
TranscriptError(TranscriptReaderError)
Transcript Reader Error.